@@ -1,24 +1,38 @@
 # -*- coding: utf-8 -*-
 """Django page CMS ``managers``."""
 from pages import settings
-from pages.utils import normalize_url, filter_link
+from pages.utils import normalize_url
 from pages.http import get_slug
 
 from django.db import models, connection
 from django.db.models import Q
 from django.core.cache import cache
-from django.contrib.auth.models import User
+from django.core.exceptions import ObjectDoesNotExist
+from django.contrib.auth.models import User, SiteProfileNotAvailable
 from django.db.models import Avg, Max, Min, Count
+from django.contrib.sites.models import Site
+from django.conf import settings as global_settings
+from django.utils.translation import ugettext_lazy as _
+
+from mptt.managers import TreeManager
 
 from datetime import datetime
 
+ISODATE_FORMAT = '%Y-%m-%dT%H:%M:%S.%f' # for parsing dates from JSON
 
-class PageManager(models.Manager):
+
+class PageManager(TreeManager):
     """
     Page manager provide several filters to obtain pages :class:`QuerySet`
     that respect the page attributes and project settings.
     """
 
+    if settings.PAGE_HIDE_SITES:
+        def get_query_set(self):
+            """Restrict operations to pages on the current site."""
+            return super(PageManager, self).get_query_set().filter(
+                sites=global_settings.SITE_ID)
+
     def populate_pages(self, parent=None, child=5, depth=5):
         """Create a population of :class:`Page <pages.models.Page>`
         for testing purpose."""
@@ -45,7 +59,7 @@ class PageManager(models.Manager):
         """
         if settings.PAGE_USE_SITE_ID:
             if not site_id:
-                site_id = settings.SITE_ID
+                site_id = global_settings.SITE_ID
             return self.filter(sites=site_id)
         return self.all()
 
@@ -66,7 +80,7 @@ class PageManager(models.Manager):
         """Filter the given pages :class:`QuerySet` to obtain only published
         page."""
         if settings.PAGE_USE_SITE_ID:
-            queryset = queryset.filter(sites=settings.SITE_ID)
+            queryset = queryset.filter(sites=global_settings.SITE_ID)
 
         queryset = queryset.filter(status=self.model.PUBLISHED)
 
@@ -132,6 +146,119 @@ class PageManager(models.Manager):
                     return page
         return None
 
+    def create_and_update_from_json_data(self, d, user):
+        """
+        Create or update page based on python dict d loaded from JSON data.
+        This applies all data except for redirect_to, which is done in a
+        second pass after all pages have been imported,
+
+        user is the User instance that will be used if the author can't
+        be found in the DB.
+
+        returns (page object, created, messages).
+
+        created is True if this was a new page or False if an existing page
+        was updated.
+
+        messages is a list of strings warnings/messages about this import
+        """
+        page = None
+        parent = None
+        parent_required = True
+        created = False
+        messages = []
+
+        page_languages = set(lang[0] for lang in settings.PAGE_LANGUAGES)
+
+        for lang, s in d['complete_slug'].items():
+            if lang not in page_languages:
+                messages.append(_("Language '%s' not imported") % (lang,))
+                continue
+
+            page = self.from_path(s, lang, exclude_drafts=False)
+            if page and page.get_complete_slug(lang) == s:
+                break
+            if parent_required and parent is None:
+                if '/' in s:
+                    parent = self.from_path(s.rsplit('/', 1)[0], lang,
+                        exclude_drafts=False)
+                else:
+                    parent_required = False
+        else:
+            # can't find an existing match, need to create a new Page
+            page = self.model(parent=parent)
+            created = True
+
+        def custom_get_user_by_email(email):
+            """
+            Allow the user profile class to look up a user by email
+            address
+            """
+            # bit of an unpleasant hack that requres the logged-in
+            # user has a profile, but I don't want to reproduce the
+            # code in get_profile() here
+            try:
+                profile = user.get_profile()
+            except (SiteProfileNotAvailable, ObjectDoesNotExist):
+                return User.objects.get(email=email)
+            get_user_by_email = getattr(profile, 'get_user_by_email', None)
+            if get_user_by_email:
+                return get_user_by_email(email)
+            return User.objects.get(email=email)
+
+        try:
+            page.author = custom_get_user_by_email(d['author_email'])
+        except (User.DoesNotExist, User.MultipleObjectsReturned):
+            page.author = user
+            messages.append(_("Original author '%s' not found")
+                % (d['author_email'],))
+
+        page.creation_date = datetime.strptime(d['creation_date'],
+            ISODATE_FORMAT)
+        page.publication_date = datetime.strptime(d['publication_date'],
+            ISODATE_FORMAT) if d['publication_date'] else None
+        page.publication_end_date = datetime.strptime(d['publication_end_date'],
+            ISODATE_FORMAT) if d['publication_end_date'] else None
+        page.last_modification_date = datetime.strptime(
+            d['last_modification_date'], ISODATE_FORMAT)
+        page.status = {
+            'published': self.model.PUBLISHED,
+            'hidden': self.model.HIDDEN,
+            'draft': self.model.DRAFT,
+            }[d['status']]
+        page.template = d['template']
+        page.redirect_to_url = d['redirect_to_url']
+
+        page.save()
+
+        if settings.PAGE_USE_SITE_ID:
+            if d['sites']:
+                for site in d['sites']:
+                    try:
+                        page.sites.add(Site.objects.get(domain=site))
+                    except Site.DoesNotExist:
+                        messages.append(_("Could not add site '%s' to page")
+                            % (site,))
+            if not settings.PAGE_HIDE_SITES and not page.sites.count():
+                # need at least one site
+                page.sites.add(Site.objects.get(pk=global_settings.SITE_ID))
+
+        from pages.models import Content
+        def create_content(lang, ctype, body):
+            Content.objects.create_content_if_changed(page, lang, ctype, body)
+
+        for lang in d['content_language_updated_order']:
+            if lang not in page_languages:
+                continue
+            create_content(lang, 'slug',
+                d['complete_slug'][lang].rsplit('/', 1)[-1])
+            create_content(lang, 'title', d['title'][lang])
+            for ctype, langs_bodies in d['content'].items():
+                create_content(lang, ctype, langs_bodies[lang])
+
+        return page, created, messages
+
+
 
 class ContentManager(models.Manager):
     """:class:`Content <pages.models.Content>` manager methods"""
@@ -250,13 +377,12 @@ class ContentManager(models.Manager):
             cache.set(key, content_dict)
 
         if language in content_dict and content_dict[language]:
-            return filter_link(content_dict[language], page, language, ctype)
+            return content_dict[language]
 
         if language_fallback:
             for lang in settings.PAGE_LANGUAGES:
                 if lang[0] in content_dict and content_dict[lang[0]]:
-                    return filter_link(content_dict[lang[0]], page, lang[0],
-                        ctype)
+                    return content_dict[lang[0]]
         return ''
 
     def get_content_slug_by_slug(self, slug):
@@ -267,7 +393,7 @@ class ContentManager(models.Manager):
         """
         content = self.filter(type='slug', body=slug)
         if settings.PAGE_USE_SITE_ID:
-            content = content.filter(page__sites__id=settings.SITE_ID)
+            content = content.filter(page__sites__id=global_settings.SITE_ID)
         try:
             content = content.latest('creation_date')
         except self.model.DoesNotExist:
