@@ -86,8 +86,9 @@ class Migration:
         # Deleting model 'PagePermission'
         db.delete_table('pages_pagepermission')
         
-        # Dropping ManyToManyField 'Page.sites'
-        db.delete_table('pages_page_sites')
+        if settings.PAGE_USE_SITE_ID:
+            # Dropping ManyToManyField 'Page.sites'
+            db.delete_table('pages_page_sites')
         
     
     page = {
@@ -104,13 +105,14 @@ class Migration:
             'redirect_to': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'redirected_pages'", 'null': 'True', 'to': "orm['pages.Page']"}),
             'redirect_to_url': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
             'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
-            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'default': '[1]', 'to': "orm['sites.Site']"}),
             'status': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
             'template': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
             'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
             }
     if settings.PAGE_TAGGING:
         page['tags'] = ('tagging.fields.TagField', [], {'null': 'True'})
+    if settings.PAGE_USE_SITE_ID:
+        page['sites'] = ('django.db.models.fields.related.ManyToManyField', [], {'default': '[1]', 'to': "orm['sites.Site']"})
         
     models = {
         'auth.group': {
