@@ -1,18 +1,23 @@
 """Django page CMS ``models``."""
 
-from pages.utils import get_placeholders, normalize_url
+from pages.utils import get_placeholders, normalize_url, get_now
 from pages.managers import PageManager, ContentManager
-from pages.managers import PageAliasManager
+from pages.managers import PageAliasManager, ISODATE_FORMAT
 from pages import settings
 
 from datetime import datetime
 from django.db import models
-from django.contrib.auth.models import User
+from django.conf import settings as django_settings
+from django.contrib.auth.models import User, SiteProfileNotAvailable
+from django.db.models import Max
 from django.utils.translation import ugettext_lazy as _
 from django.utils.safestring import mark_safe
 from django.core.cache import cache
 from django.core.urlresolvers import reverse
+from django.core.exceptions import ObjectDoesNotExist
 from django.contrib.sites.models import Site
+from django.conf import settings as global_settings
+
 
 from mptt.models import MPTTModel
 if settings.PAGE_TAGGING:
@@ -63,12 +68,12 @@ class Page(MPTTModel):
     PAGE_URL_KEY = "page_%d_url"
     PAGE_BROKEN_LINK_KEY = "page_broken_link_%s"
 
-    author = models.ForeignKey(User, verbose_name=_('author'))
+    author = models.ForeignKey(django_settings.AUTH_USER_MODEL, verbose_name=_('author'))
 
     parent = models.ForeignKey('self', null=True, blank=True,
             related_name='children', verbose_name=_('parent'))
     creation_date = models.DateTimeField(_('creation date'), editable=False,
-            default=datetime.now)
+            default=get_now)
     publication_date = models.DateTimeField(_('publication date'),
             null=True, blank=True, help_text=_('''When the page should go
             live. Status must be "Published" for page to go live.'''))
@@ -90,7 +95,8 @@ class Page(MPTTModel):
             after this date.'''))
 
     if settings.PAGE_USE_SITE_ID:
-        sites = models.ManyToManyField(Site, default=[settings.SITE_ID],
+        sites = models.ManyToManyField(Site,
+                default=lambda: [global_settings.SITE_ID],
                 help_text=_('The site(s) the page is accessible at.'),
                 verbose_name=_('sites'))
 
@@ -128,22 +134,22 @@ class Page(MPTTModel):
             self.status = self.DRAFT
         # Published pages should always have a publication date
         if self.publication_date is None and self.status == self.PUBLISHED:
-            self.publication_date = datetime.now()
+            self.publication_date = get_now()
         # Drafts should not, unless they have been set to the future
         if self.status == self.DRAFT:
             if settings.PAGE_SHOW_START_DATE:
                 if (self.publication_date and
-                        self.publication_date <= datetime.now()):
+                        self.publication_date <= get_now()):
                     self.publication_date = None
             else:
                 self.publication_date = None
-        self.last_modification_date = datetime.now()
+        self.last_modification_date = get_now()
         # let's assume there is no more broken links after a save
         cache.delete(self.PAGE_BROKEN_LINK_KEY % self.id)
         super(Page, self).save(*args, **kwargs)
         # fix sites many-to-many link when the're hidden from the form
         if settings.PAGE_HIDE_SITES and self.sites.count() == 0:
-            self.sites.add(Site.objects.get(pk=settings.SITE_ID))
+            self.sites.add(Site.objects.get(pk=global_settings.SITE_ID))
 
     def _get_calculated_status(self):
         """Get the calculated status of the page based on
@@ -151,11 +157,11 @@ class Page(MPTTModel):
         :attr:`Page.publication_end_date`,
         and :attr:`Page.status`."""
         if settings.PAGE_SHOW_START_DATE and self.publication_date:
-            if self.publication_date > datetime.now():
+            if self.publication_date > get_now():
                 return self.DRAFT
 
         if settings.PAGE_SHOW_END_DATE and self.publication_end_date:
-            if self.publication_end_date < datetime.now():
+            if self.publication_end_date < get_now():
                 return self.EXPIRED
 
         return self.status
@@ -166,6 +172,10 @@ class Page(MPTTModel):
         return self.calculated_status in (self.PUBLISHED, self.HIDDEN)
     visible = property(_visible)
 
+    def published_children(self):
+        """Return a :class:`QuerySet` of published children page"""
+        return Page.objects.filter_published(self.get_children())
+
     def get_children_for_frontend(self):
         """Return a :class:`QuerySet` of published children page"""
         return Page.objects.filter_published(self.get_children())
@@ -442,6 +452,101 @@ class Page(MPTTModel):
         """Used in the admin menu to create the left margin."""
         return self.level * 2
 
+    def dump_json_data(self):
+        """
+        Return a python dict representation of this page for use as part of
+        a JSON export.
+        """
+        def content_langs_ordered():
+            """
+            Return a list of languages ordered by the page content
+            with the latest creation date in each.  This will be used
+            to maintain the state of the language_up_to_date template
+            tag when a page is restored or imported into another site.
+            """
+            params = {'page': self}
+            if self.freeze_date:
+                params['creation_date__lte'] = self.freeze_date
+            cqs = Content.objects.filter(**params)
+            cqs = cqs.values('language').annotate(latest=Max('creation_date'))
+            return [c['language'] for c in cqs.order_by('latest')]
+        languages = content_langs_ordered()
+
+        def language_content(ctype):
+            return dict(
+                (lang, self.get_content(lang, ctype, language_fallback=False))
+                for lang in languages)
+
+        def placeholder_content():
+            """Return content of each placeholder in each language."""
+            out = {}
+            for p in get_placeholders(self.get_template()):
+                if p.name in ('title', 'slug'):
+                    continue # these were already included
+                out[p.name] = language_content(p.name)
+            return out
+
+        def isoformat(d):
+            return None if d is None else d.strftime(ISODATE_FORMAT)
+
+        def custom_email(user):
+            """Allow a user's profile to return an email for the user."""
+            try:
+                profile = user.get_profile()
+            except (SiteProfileNotAvailable, ObjectDoesNotExist):
+                return user.email
+            get_email = getattr(profile, 'get_email', None)
+            return get_email() if get_email else user.email
+
+        return {
+            'complete_slug': dict(
+                (lang, self.get_complete_slug(lang, hideroot=False))
+                for lang in languages),
+            'title': language_content('title'),
+            'author_email': custom_email(self.author),
+            'creation_date': isoformat(self.creation_date),
+            'publication_date': isoformat(self.publication_date),
+            'publication_end_date': isoformat(self.publication_end_date),
+            'last_modification_date': isoformat(self.last_modification_date),
+            'status': {
+                Page.PUBLISHED: 'published',
+                Page.HIDDEN: 'hidden',
+                Page.DRAFT: 'draft'}[self.status],
+            'template': self.template,
+            'sites': (
+                [site.domain for site in self.sites.all()]
+                if settings.PAGE_USE_SITE_ID else []),
+            'redirect_to_url': self.redirect_to_url,
+            'redirect_to_complete_slug': dict(
+                (lang, self.redirect_to.get_complete_slug(
+                    lang, hideroot=False))
+                for lang in self.redirect_to.get_languages()
+                ) if self.redirect_to is not None else None,
+            'content': placeholder_content(),
+            'content_language_updated_order': languages,
+        }
+
+    def update_redirect_to_from_json(self, redirect_to_complete_slugs):
+        """
+        The second pass of PageManager.create_and_update_from_json_data
+        used to update the redirect_to field.
+
+        Returns a messages list to be appended to the messages from the
+        first pass.
+        """
+        messages = []
+        s = ''
+        for lang, s in redirect_to_complete_slugs.items():
+            r = Page.objects.from_path(s, lang, exclude_drafts=False)
+            if r:
+                self.redirect_to = r
+                self.save()
+                break
+        else:
+            messages.append(_("Could not find page for redirect-to field"
+                " '%s'") % (s,))
+        return messages
+
     def __unicode__(self):
         """Representation of the page, saved or not."""
         if self.id:
@@ -465,7 +570,7 @@ class Content(models.Model):
     page = models.ForeignKey(Page, verbose_name=_('page'))
 
     creation_date = models.DateTimeField(_('creation date'), editable=False,
-        default=datetime.now)
+        default=get_now)
     objects = ContentManager()
 
     class Meta:
