@@ -240,6 +240,14 @@ class PlaceholderNode(template.Node):
     def __repr__(self):
         return "<Placeholder Node: %s>" % self.name
 
+def get_filename(page, placeholder, data):
+    filename = os.path.join(
+        settings.PAGE_UPLOAD_ROOT,
+        'page_' + str(page.id),
+        placeholder.name + '-' + str(time.time()) + '-' + str(data)
+    )
+    return filename
+
 
 class ImagePlaceholderNode(PlaceholderNode):
     """A `PlaceholderNode` that saves one image on disk.
@@ -270,16 +278,8 @@ class ImagePlaceholderNode(PlaceholderNode):
             # the image URL is posted if not changed
             if type(data) is unicode:
                 return
-            filename = os.path.join(
-                settings.PAGE_UPLOAD_ROOT,
-                'page_' + str(page.id),
-                self.name + '-' + str(time.time())
-            )
-
-            m = re.search('\.[a-zA-Z]{1,4}$', str(data))
-            if m is not None:
-                filename += m.group(0).lower()
 
+            filename = get_filename(page, self, data)
             filename = default_storage.save(filename, data)
             return super(ImagePlaceholderNode, self).save(
                 page,
@@ -317,16 +317,8 @@ class FilePlaceholderNode(PlaceholderNode):
             # the image URL is posted if not changed
             if type(data) is unicode:
                 return
-            filename = os.path.join(
-                settings.PAGE_UPLOAD_ROOT,
-                'page_' + str(page.id),
-                self.name + '-' + str(time.time())
-            )
-
-            m = re.search('\.[a-zA-Z]{1,4}$', str(data))
-            if m is not None:
-                filename += m.group(0).lower()
 
+            filename = get_filename(page, self, data)
             filename = default_storage.save(filename, data)
             return super(FilePlaceholderNode, self).save(
                 page,
