@@ -98,20 +98,23 @@ class Details(object):
             exclude_drafts=(not is_staff))
         if page:
             return page
-        # if the complete path didn't worked out properly we gonna
+        # if the complete path didn't worked out properly 
+        # and if didn't used PAGE_USE_STRICT_URL setting we gonna
         # try to see if it might be a delegation page.
         # To do that we remove the right part of the url and try again
         # to find a page that match
-        path = remove_slug(path)
-        while path is not None:
-            page = Page.objects.from_path(path, lang,
-                exclude_drafts=(not is_staff))
-            # find a match. Is the page delegating?
-            if page:
-                if page.delegate_to:
-                    return page
+        if not settings.PAGE_USE_STRICT_URL:
             path = remove_slug(path)
-        return page
+            while path is not None:
+                page = Page.objects.from_path(path, lang,
+                    exclude_drafts=(not is_staff))
+                # find a match. Is the page delegating?
+                if page:
+                    if page.delegate_to:
+                        return page
+                path = remove_slug(path)
+                
+        return None
 
     def resolve_alias(self, request, path, lang):
         alias = PageAlias.objects.from_path(request, path, lang)
@@ -191,9 +194,9 @@ class Details(object):
             return view(request, *args, **kwargs)
 
 
-# The view view instance. It's the same object for
+# The Details view instance. It's the same object for
 # everybody so be careful to maintain it thread safe.
-# ie: NO self.attrbitute = something
+# ie: NO self.attribute = something
 details = Details()
 
 
